import { Badge, badgeVariants } from "@/components/ui/badge";
import { cn } from "@/lib/utils";

const femaleTagPrefix = "female:";
const maleTagPrefix = "male:";

function getTagKind(tagname: string) {
    if (tagname.startsWith(femaleTagPrefix)) {
        return "female";
    }
    if (tagname.startsWith(maleTagPrefix)){
        return "male";
    }
    return "default";
}

function toPrettyTagname(tagname: string): string {
    const kind = getTagKind(tagname);
    switch (kind) {
        case "male":
            return `♂ ${tagname.slice(maleTagPrefix.length)}`;
        case "female":
            return `♀ ${tagname.slice(femaleTagPrefix.length)}`;
        default:
            return tagname;
    }
}

export default function TagBadge(props: { tagname: string, className?: string}) {
    const { tagname } = props;
    const kind = getTagKind(tagname);
    return <li className={
        cn( badgeVariants({ variant: "default"}) ,
            "px-1",
            kind === "male" && "bg-[#2a7bbf] hover:bg-[#3091e7]",
            kind === "female" && "bg-[#c21f58] hover:bg-[#db2d67]",
            kind === "default" && "bg-[#4a5568] hover:bg-[#718096]",
            props.className,
        )
    }>{toPrettyTagname(tagname)}</li>;
}